@@ -16,7 +16,7 @@ pub struct AzureConfig<'a> {
     pub subscription_aliases: HashMap<String, &'a str>,
 }
 
-impl<'a> Default for AzureConfig<'a> {
+impl Default for AzureConfig<'_> {
     fn default() -> Self {
         AzureConfig {
             format: "on [$symbol($subscription)]($style) ",
