@@ -19,7 +19,7 @@ pub struct CharacterConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for CharacterConfig<'a> {
+impl Default for CharacterConfig<'_> {
     fn default() -> Self {
         CharacterConfig {
             format: "$symbol ",
