@@ -13,6 +13,7 @@ pub struct DirenvConfig<'a> {
     pub style: &'a str,
     pub disabled: bool,
     pub detect_extensions: Vec<&'a str>,
+    pub detect_env_vars: Vec<&'a str>,
     pub detect_files: Vec<&'a str>,
     pub detect_folders: Vec<&'a str>,
     pub allowed_msg: &'a str,
@@ -22,7 +23,7 @@ pub struct DirenvConfig<'a> {
     pub unloaded_msg: &'a str,
 }
 
-impl<'a> Default for DirenvConfig<'a> {
+impl Default for DirenvConfig<'_> {
     fn default() -> Self {
         Self {
             format: "[$symbol$loaded/$allowed]($style) ",
@@ -30,6 +31,7 @@ impl<'a> Default for DirenvConfig<'a> {
             style: "bold bright-yellow",
             disabled: true,
             detect_extensions: vec![],
+            detect_env_vars: vec!["DIRENV_FILE"],
             detect_files: vec![".envrc"],
             detect_folders: vec![],
             allowed_msg: "allowed",
