@@ -14,7 +14,7 @@ pub struct GuixShellConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for GuixShellConfig<'a> {
+impl Default for GuixShellConfig<'_> {
     fn default() -> Self {
         GuixShellConfig {
             format: "via [$symbol]($style) ",
