@@ -16,7 +16,7 @@ pub struct MesonConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for MesonConfig<'a> {
+impl Default for MesonConfig<'_> {
     fn default() -> Self {
         MesonConfig {
             truncation_length: u32::MAX,
